package com.example.flutter_screen_light_plugin;

import androidx.annotation.NonNull;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import android.util.Log;

/** FlutterScreenLightPlugin */
public class FlutterScreenLightPlugin implements FlutterPlugin, MethodCallHandler, ActivityAware {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private MethodChannel channel;
  private SGTScreenLightManage screenLightManage;

  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {

    screenLightManage = new SGTScreenLightManage(flutterPluginBinding.getApplicationContext());

    channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "flutter_screen_light_plugin");
    channel.setMethodCallHandler(this);
  }

  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
    if (call.method.equals("getPlatformVersion")) {
      result.success("Android " + android.os.Build.VERSION.RELEASE);
    }else if(call.method.equals("getCurrentScreenLight"))  {
      result.success(screenLightManage.getCurrentScreenLight());
    }else if(call.method.equals("setScreenLight")) {
      double volumeValue = Double.parseDouble(call.argument("light").toString());
      screenLightManage.setScreenLight(volumeValue);
    }else if (call.method.equals("getScreenMaxLight")){
      result.success(screenLightManage.getScreenMaxLight());
    } else {
      result.notImplemented();
    }
  }


  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    channel.setMethodCallHandler(null);
    Log.d(SGTScreenLightManage.TAG, "onDetachedFromEngine");
    screenLightManage = null;
  }

  @Override
  public void onAttachedToActivity(ActivityPluginBinding binding)
  {
    Log.d(SGTScreenLightManage.TAG, "onAttachedToActivity");

    screenLightManage.setActivity(binding.getActivity());
  }

  @Override
  public void onDetachedFromActivityForConfigChanges()
  {
    Log.d(SGTScreenLightManage.TAG, "onDetachedFromActivityForConfigChanges");

  }

  @Override
  public void onReattachedToActivityForConfigChanges(ActivityPluginBinding binding)
  {
    Log.d(SGTScreenLightManage.TAG, "onReattachedToActivityForConfigChanges");

  }

  @Override
  public void onDetachedFromActivity()
  {

  }


}
